@@ -1,4 +1,5 @@
-### This file is part of the `foreign' library for R and related languages.
+### This file is part of the `foreign' package for R.
+
 ### It is made available under the terms of the GNU General Public
 ### License, version 2, or at your option, any later version,
 ### incorporated herein by reference.
@@ -10,12 +11,10 @@
 ### details.
 ###
 ### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### License along with this program; if not, a copy is available at
+### http://www.r-project.org/Licenses/
 
-.onLoad <- .First.lib <- function(lib, pkg) {
+.onLoad <- .First.lib <- function(lib, pkg)
     .C("spss_init", PACKAGE = "foreign")
-}
 
 .noGenerics <- TRUE
