@@ -24,6 +24,8 @@
 #include <ctype.h>
 #include <errno.h>
 #include <math.h>
+#include <float.h>
+#include <limits.h>
 #include "foreign.h"
 #include "avl.h"
 #include "file-handle.h"
